@@ -6,20 +6,20 @@ pub mod types;
 pub const EAPI_VERSION: u16 = 1;
 
 pub mod prelude {
-    pub use crate::need_ready;
-    pub use crate::rpc_need_ready;
-    pub use crate::service::block;
-    pub use crate::service::handle_default_rpc;
-    pub use crate::service::init_logs;
-    pub use crate::service::mark_ready;
-    pub use crate::service::mark_terminating;
-    pub use crate::service::read_initial;
-    pub use crate::service::safe_rpc_call;
-    pub use crate::service::start_signal_handlers;
+    pub use crate::service::svc_block;
+    pub use crate::service::svc_handle_default_rpc;
+    pub use crate::service::svc_launch;
+    pub use crate::service::svc_init_logs;
     pub use crate::service::svc_is_active;
     pub use crate::service::svc_is_terminating;
-    pub use crate::service::terminate;
-    pub use crate::service::wait_core;
+    pub use crate::service::svc_mark_ready;
+    pub use crate::service::svc_mark_terminating;
+    pub use crate::service::svc_safe_rpc_call;
+    pub use crate::service::svc_start_signal_handlers;
+    pub use crate::service::svc_terminate;
+    pub use crate::service::svc_wait_core;
+    pub use crate::svc_need_ready;
+    pub use crate::svc_rpc_need_ready;
     pub use elbus::client::AsyncClient;
     pub use elbus::rpc::{Rpc, RpcClient, RpcError, RpcEvent, RpcHandlers, RpcResult};
     pub use elbus::{Frame, QoS};
