@@ -14,6 +14,7 @@ use log::{Level, Log};
 use serde::Deserialize;
 use std::collections::HashMap;
 use std::io::Read;
+use std::path::Path;
 use std::sync::atomic;
 use std::sync::Arc;
 use std::sync::Mutex;
@@ -69,7 +70,7 @@ pub fn set_poc(panic_in: Option<Duration>) {
 ///
 /// Will panic if the mutex is poisoned
 pub fn poc() {
-    terminate();
+    svc_terminate();
     if let Some(delay) = *NEED_PANIC.lock().unwrap() {
         bmart::process::suicide(delay + Duration::from_secs(1), false);
         std::thread::spawn(move || {
@@ -79,12 +80,12 @@ pub fn poc() {
     }
 }
 
-pub fn handle_default_rpc(method: &str, info: &services::ServiceInfo) -> RpcResult {
+pub fn svc_handle_default_rpc(method: &str, info: &services::ServiceInfo) -> RpcResult {
     match method {
         "test" => Ok(None),
         "info" => Ok(Some(rmp_serde::to_vec_named(info)?)),
         "stop" => {
-            terminate();
+            svc_terminate();
             Ok(None)
         }
         _ => Err(RpcError::method(None)),
@@ -92,7 +93,7 @@ pub fn handle_default_rpc(method: &str, info: &services::ServiceInfo) -> RpcResu
 }
 
 #[inline]
-pub async fn safe_rpc_call(
+pub async fn svc_safe_rpc_call(
     rpc: &RpcClient,
     target: &str,
     method: &str,
@@ -106,7 +107,7 @@ pub async fn safe_rpc_call(
 }
 
 #[inline]
-pub async fn wait_core(rpc: &RpcClient, timeout: Duration, wait_forever: bool) -> EResult<()> {
+pub async fn svc_wait_core(rpc: &RpcClient, timeout: Duration, wait_forever: bool) -> EResult<()> {
     #[derive(Deserialize)]
     struct TR {
         active: bool,
@@ -118,7 +119,7 @@ pub async fn wait_core(rpc: &RpcClient, timeout: Duration, wait_forever: bool) -
                 "core load wait aborted, the service is not active",
             ));
         }
-        if let Ok(ev) = safe_rpc_call(
+        if let Ok(ev) = svc_safe_rpc_call(
             rpc,
             "eva.core",
             "test",
@@ -155,7 +156,7 @@ pub fn svc_is_terminating() -> bool {
 }
 
 #[macro_export]
-macro_rules! need_ready {
+macro_rules! svc_need_ready {
     () => {
         if !svc_is_active() {
             return;
@@ -164,7 +165,7 @@ macro_rules! need_ready {
 }
 
 #[macro_export]
-macro_rules! rpc_need_ready {
+macro_rules! svc_rpc_need_ready {
     () => {
         if !svc_is_active() {
             return Err(Error::not_ready("service is not ready").into());
@@ -192,14 +193,14 @@ struct BusLogger {}
 
 /// Terminate the service (canceling block)
 #[inline]
-pub fn terminate() {
+pub fn svc_terminate() {
     ACTIVE.store(false, atomic::Ordering::SeqCst);
     TERMINATING.store(true, atomic::Ordering::SeqCst);
 }
 
 /// Block the service until terminate is called
 #[inline]
-pub async fn block(rpc: &RpcClient) {
+pub async fn svc_block(rpc: &RpcClient) {
     while svc_is_active() && rpc.is_connected() {
         sleep(SLEEP_STEP).await;
     }
@@ -249,7 +250,7 @@ async fn handle_logs<C: ?Sized>(
 /// # Panics
 ///
 /// Will panic if the mutex is poisoned
-pub fn init_logs<C: ?Sized>(
+pub fn svc_init_logs<C: ?Sized>(
     initial: &services::Initial,
     client: Arc<tokio::sync::Mutex<C>>,
 ) -> EResult<()>
@@ -272,7 +273,7 @@ where
 /// # Panics
 ///
 /// Will panic only if rmp_serde is broken
-pub async fn mark_ready<C: ?Sized>(client: &tokio::sync::Mutex<C>) -> EResult<()>
+pub async fn svc_mark_ready<C: ?Sized>(client: &tokio::sync::Mutex<C>) -> EResult<()>
 where
     C: AsyncClient + 'static,
 {
@@ -298,7 +299,7 @@ where
 /// # Panics
 ///
 /// Will panic only if rmp_serde is broken
-pub async fn mark_terminating<C: ?Sized>(client: &tokio::sync::Mutex<C>) -> EResult<()>
+pub async fn svc_mark_terminating<C: ?Sized>(client: &tokio::sync::Mutex<C>) -> EResult<()>
 where
     C: AsyncClient + 'static,
 {
@@ -323,12 +324,12 @@ where
 /// Start service signal handlers (SIGTERM and SIGINT)
 ///
 /// Calls the terminate method when received
-pub fn start_signal_handlers() {
+pub fn svc_start_signal_handlers() {
     macro_rules! handle_signal {
         ($signal: expr) => {{
             tokio::spawn(async move {
                 signal($signal).unwrap().recv().await;
-                terminate();
+                svc_terminate();
             });
         }};
     }
@@ -375,3 +376,40 @@ pub fn read_initial_sync() -> EResult<services::Initial> {
     std::io::stdin().read_to_end(&mut buf)?;
     process_initial(&buf)
 }
+
+pub fn svc_launch<L, LFut>(launcher: L) -> EResult<()>
+where
+    L: FnMut(services::Initial) -> LFut,
+    LFut: std::future::Future<Output = EResult<()>>,
+{
+    let initial = read_initial_sync()?;
+    let rt = tokio::runtime::Builder::new_multi_thread()
+        .worker_threads(initial.workers() as usize)
+        .enable_all()
+        .build()?;
+    rt.block_on(launch(launcher, initial))?;
+    Ok(())
+}
+
+async fn launch<L, LFut>(mut launcher: L, mut initial: services::Initial) -> EResult<()>
+where
+    L: FnMut(services::Initial) -> LFut,
+    LFut: std::future::Future<Output = EResult<()>>,
+{
+    let op = eva_common::op::Op::new(initial.startup_timeout());
+    let eva_dir = initial.eva_dir().to_owned();
+    if let Some(ref prepare_command) = initial.prepare_command() {
+        let cmd = format!("cd \"{}\" && {}", eva_dir, prepare_command);
+        let res = bmart::process::command("sh", ["-c", &cmd], op.timeout()?, None, None).await?;
+        if !res.ok() {
+            return Err(Error::failed(format!(
+                "prepare command failed: {}",
+                res.err.join("\n")
+            )));
+        }
+    }
+    initial
+        .extend_config(op.timeout()?, &Path::new(&eva_dir))
+        .await?;
+    launcher(initial).await
+}
